@@ -12,8 +12,9 @@ use Carp;
 use Readonly;
 Readonly my $HALF          => 0.5;
 Readonly my $CURSOR_PIXELS => 5;
+Readonly my $MAX_ZOOM      => 100;
 
-our $VERSION = '2.6.7';
+our $VERSION = '2.8.2';
 
 my %cursorhash = (
     left => {
@@ -72,8 +73,8 @@ use Glib::Object::Subclass Gtk3::DrawingArea::, signals => {
         'zoom',                             # name
         'zoom',                             # nick
         'zoom level',                       # blurb
-        0.0001,                             # minimum
-        1000.0,                             # maximum
+        0.001,                              # minimum
+        100.0,                              # maximum
         1.0,                                # default_value
         [qw/readable writable/]             # flags
     ),
@@ -147,7 +148,7 @@ sub INIT_INSTANCE {
               )
         );
     }
-    $self->set_tool('dragger');
+    $self->set_tool('selector');
     $self->set_redraw_on_allocate(FALSE);
     return $self;
 }
@@ -273,6 +274,7 @@ sub _button_released {
     if ( $self->get_tool eq 'selector' ) {
         $self->_update_selection($event);
     }
+    $self->set_tool('selector');
     return;
 }
 
@@ -417,7 +419,7 @@ sub _draw {
 sub _configure_event {
     my ( $self, $event ) = @_;
     if ( $self->get_zoom_to_fit ) {
-        $self->_calculate_zoom_to_fit;
+        $self->zoom_to_box( $self->get_pixbuf_size );
     }
     return;
 }
@@ -433,6 +435,7 @@ sub set_zoom {
 
 sub _set_zoom {
     my ( $self, $zoom ) = @_;
+    if ( $zoom > $MAX_ZOOM ) { $zoom = $MAX_ZOOM }
     $self->set( 'zoom', $zoom );
     return;
 }
@@ -496,26 +499,34 @@ sub set_zoom_to_fit {
     my ( $self, $zoom_to_fit ) = @_;
     $self->set( 'zoom-to-fit', $zoom_to_fit );
     if ( not $zoom_to_fit ) { return }
-    $self->_calculate_zoom_to_fit;
+    $self->zoom_to_box( $self->get_pixbuf_size );
     return;
 }
 
-sub _calculate_zoom_to_fit {
-    my ($self) = @_;
-    my $pixbuf_size = $self->get_pixbuf_size;
-    if ( not defined $pixbuf_size ) { return }
+sub zoom_to_box {
+    my ( $self, $box, $additional_factor ) = @_;
+    if ( not defined $box ) { return }
+    if ( not defined $box->{x} )          { $box->{x}          = 0 }
+    if ( not defined $box->{y} )          { $box->{y}          = 0 }
+    if ( not defined $additional_factor ) { $additional_factor = 1 }
     my $allocation  = $self->get_allocation;
     my $ratio       = $self->get_resolution_ratio;
-    my $sc_factor_w = $allocation->{width} / $pixbuf_size->{width} * $ratio;
-    my $sc_factor_h = $allocation->{height} / $pixbuf_size->{height};
+    my $sc_factor_w = $allocation->{width} / $box->{width} * $ratio;
+    my $sc_factor_h = $allocation->{height} / $box->{height};
     $self->_set_zoom_with_center(
-        min( $sc_factor_w, $sc_factor_h ),
-        $pixbuf_size->{width} / $ratio / 2,
-        $pixbuf_size->{height} / 2
+        min( $sc_factor_w, $sc_factor_h ) * $additional_factor,
+        ( $box->{x} + $box->{width} / 2 ) / $ratio,
+        $box->{y} + $box->{height} / 2
     );
     return;
 }
 
+sub zoom_to_selection {
+    my ( $self, $context_factor ) = @_;
+    $self->zoom_to_box( $self->get_selection, $context_factor );
+    return;
+}
+
 sub get_zoom_to_fit {
     my ($self) = @_;
     return $self->get('zoom-to-fit');
@@ -647,7 +658,7 @@ sub set_resolution_ratio {
     my ( $self, $ratio ) = @_;
     $self->set( 'resolution-ratio', $ratio );
     if ( $self->get_zoom_to_fit ) {
-        $self->_calculate_zoom_to_fit;
+        $self->zoom_to_box( $self->get_pixbuf_size );
     }
     return;
 }
